Reprocess — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »

# Reprocess

## Introduction

This program recreates the hourly, daily and monthly summary data that is created by the Process.py program. It should be run whenever you upgrade to a newer version of pywws.

The program is very simple to use:

    python -m pywws.Reprocess data_directory

where `data_directory` is the location of your stored data.

## Detailed API

Regenerate hourly and daily summary data

    usage: python -m pywws.Reprocess [options] data_dir
    options are:
     -h | --help     display this help
     -v | --verbose  increase number of informative messages
    data_dir is the root directory of the weather data

Functions

`Reprocess`(data_dir) |
`main`([argv]) |

`pywws.Reprocess.` `Reprocess`(data_dir)

`pywws.Reprocess.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »